==> openttd-1.9.0-beta1-docs.tar.tar: openttd-1.9.0-beta1-docs/html/dd/d03/structBaseStation.js <==
var structBaseStation =
[
    [ "BaseStation", "dd/d03/structBaseStation.html#a9905e35930fd4794020343db730cd130", null ],
    [ "~BaseStation", "dd/d03/structBaseStation.html#a212490a9b30dec2eee3aa623cb88320a", null ],
    [ "GetByTile", "dd/d03/structBaseStation.html#ad790753c33022b5bbb087d568ec7aa5c", null ],
    [ "GetNewGRFVariable", "dd/d03/structBaseStation.html#aa8a474edae88c7768e186e29889fbc6c", null ],
    [ "GetPlatformLength", "dd/d03/structBaseStation.html#a05d688fd8fbafa5e22c19ba48b444270", null ],
    [ "GetPlatformLength", "dd/d03/structBaseStation.html#a2c9e9dd443dfd12a5ed4ee776c657b58", null ],
    [ "GetTileArea", "dd/d03/structBaseStation.html#a5d2ac5f6e47c730fadc993986ece70e5", null ],
    [ "IsInUse", "dd/d03/structBaseStation.html#a906ef985b20fd4a2fd404429e6d7dc50", null ],
    [ "PostDestructor", "dd/d03/structBaseStation.html#a88aef71d6caf3001844715ced4aeaae9", null ],
    [ "TileBelongsToRailStation", "dd/d03/structBaseStation.html#ab419f90f8a017bf87f286edc749d1985", null ],
    [ "UpdateVirtCoord", "dd/d03/structBaseStation.html#a6048290644e74ccafefc6a8c0a0cd1b4", null ],
    [ "build_date", "dd/d03/structBaseStation.html#a868d6223a9cbfeb8e6d85d9e039b9bdf", null ],
    [ "cached_anim_triggers", "dd/d03/structBaseStation.html#a9cacf0431afa14b3fda2eadae2931aa1", null ],
    [ "cached_cargo_triggers", "dd/d03/structBaseStation.html#afdec0eedecbc139f01e8d90b461ffe16", null ],
    [ "delete_ctr", "dd/d03/structBaseStation.html#a5d1dcb931ca3ba5a093022a6b30d1710", null ],
    [ "facilities", "dd/d03/structBaseStation.html#a79845cbd390542e75e2d8962dc6b81ee", null ],
    [ "name", "dd/d03/structBaseStation.html#afef48527c065d2e2327b060bc7ee753a", null ],
    [ "num_specs", "dd/d03/structBaseStation.html#a9fd47fb8fdaa3a301f56f403d2c1a5a0", null ],
    [ "owner", "dd/d03/structBaseStation.html#aa367d4a6d4864abdc1b42a7f6116db47", null ],
    [ "random_bits", "dd/d03/structBaseStation.html#a3d70d67b5b5bf0840e4914ac6924d87e", null ],
    [ "rect", "dd/d03/structBaseStation.html#a70526f8027662b7c47ded8872b8b5a44", null ],
    [ "sign", "dd/d03/structBaseStation.html#aebeb71cbb3639859dbff279b1604c262", null ],
    [ "speclist", "dd/d03/structBaseStation.html#aa572a9173222658392915a81473e3f83", null ],
    [ "string_id", "dd/d03/structBaseStation.html#a0603805733f25908dccde261d2be8e1b", null ],
    [ "town", "dd/d03/structBaseStation.html#aaeef278c06e4bce134c80022712c2326", null ],
    [ "train_station", "dd/d03/structBaseStation.html#a29fad5483f74c05cc42c486ecdd8c797", null ],
    [ "waiting_triggers", "dd/d03/structBaseStation.html#a76a45e5105d79d484deac81eceb71429", null ],
    [ "xy", "dd/d03/structBaseStation.html#a0c6e2a00f6b349bc088676407e3d8b0a", null ]
];

==> openttd-1.11.0-beta1-docs.tar.tar: openttd-1.11.0-beta1-docs/html/dd/d03/structBaseStation.js <==
var structBaseStation =
[
    [ "BaseStation", "dd/d03/structBaseStation.html#a9905e35930fd4794020343db730cd130", null ],
    [ "~BaseStation", "dd/d03/structBaseStation.html#a212490a9b30dec2eee3aa623cb88320a", null ],
    [ "FillCachedName", "dd/d03/structBaseStation.html#ab4203cc09669f1dc37af53075ede4418", null ],
    [ "GetByTile", "dd/d03/structBaseStation.html#ad790753c33022b5bbb087d568ec7aa5c", null ],
    [ "GetCachedName", "dd/d03/structBaseStation.html#a77f34bae9349897e5bff8422fa72572d", null ],
    [ "GetNewGRFVariable", "dd/d03/structBaseStation.html#aa8a474edae88c7768e186e29889fbc6c", null ],
    [ "GetPlatformLength", "dd/d03/structBaseStation.html#a05d688fd8fbafa5e22c19ba48b444270", null ],
    [ "GetPlatformLength", "dd/d03/structBaseStation.html#a2c9e9dd443dfd12a5ed4ee776c657b58", null ],
    [ "GetTileArea", "dd/d03/structBaseStation.html#a5d2ac5f6e47c730fadc993986ece70e5", null ],
    [ "IsInUse", "dd/d03/structBaseStation.html#a906ef985b20fd4a2fd404429e6d7dc50", null ],
    [ "MoveSign", "dd/d03/structBaseStation.html#a1494a904238e39864768e215299ee598", null ],
    [ "PostDestructor", "dd/d03/structBaseStation.html#a88aef71d6caf3001844715ced4aeaae9", null ],
    [ "TileBelongsToRailStation", "dd/d03/structBaseStation.html#ab419f90f8a017bf87f286edc749d1985", null ],
    [ "UpdateVirtCoord", "dd/d03/structBaseStation.html#a6048290644e74ccafefc6a8c0a0cd1b4", null ],
    [ "build_date", "dd/d03/structBaseStation.html#a868d6223a9cbfeb8e6d85d9e039b9bdf", null ],
    [ "cached_anim_triggers", "dd/d03/structBaseStation.html#a9cacf0431afa14b3fda2eadae2931aa1", null ],
    [ "cached_cargo_triggers", "dd/d03/structBaseStation.html#afdec0eedecbc139f01e8d90b461ffe16", null ],
    [ "cached_name", "dd/d03/structBaseStation.html#a25acac0acadab77925a765d4bd6d3924", null ],
    [ "delete_ctr", "dd/d03/structBaseStation.html#a5d1dcb931ca3ba5a093022a6b30d1710", null ],
    [ "facilities", "dd/d03/structBaseStation.html#a03cfe47903b03874be99d22d7d4da85b", null ],
    [ "name", "dd/d03/structBaseStation.html#aeb6835b7723ffeca9b95c615316a37fd", null ],
    [ "num_specs", "dd/d03/structBaseStation.html#a9fd47fb8fdaa3a301f56f403d2c1a5a0", null ],
    [ "owner", "dd/d03/structBaseStation.html#a55ba378d4e9ed0fa9f40b84e97608347", null ],
    [ "random_bits", "dd/d03/structBaseStation.html#a3d70d67b5b5bf0840e4914ac6924d87e", null ],
    [ "rect", "dd/d03/structBaseStation.html#a70526f8027662b7c47ded8872b8b5a44", null ],
    [ "sign", "dd/d03/structBaseStation.html#ad516937d863d57753100be987c3edd6b", null ],
    [ "speclist", "dd/d03/structBaseStation.html#aa572a9173222658392915a81473e3f83", null ],
    [ "string_id", "dd/d03/structBaseStation.html#a0603805733f25908dccde261d2be8e1b", null ],
    [ "town", "dd/d03/structBaseStation.html#aaeef278c06e4bce134c80022712c2326", null ],
    [ "train_station", "dd/d03/structBaseStation.html#a29fad5483f74c05cc42c486ecdd8c797", null ],
    [ "waiting_triggers", "dd/d03/structBaseStation.html#a76a45e5105d79d484deac81eceb71429", null ],
    [ "xy", "dd/d03/structBaseStation.html#a0c6e2a00f6b349bc088676407e3d8b0a", null ]
];
